python-miss is a collection of generic functions and classes.

Installation
============

	pip install miss

python-miss doesn't have dependencies and is compatible with python 2 and 3.

Usage
=====

There is no documentation yet, the source code should be self-explanatory and
contains some docstrings, except for the six module for which you can read the
original documentation at http://packages.python.org/six

License
=======

LGPLv3+
